summaryrefslogtreecommitdiff
path: root/file.c
diff options
context:
space:
mode:
Diffstat (limited to 'file.c')
-rw-r--r--file.c5
1 files changed, 3 insertions, 2 deletions
diff --git a/file.c b/file.c
index 854d52ec69..5248ba3fda 100644
--- a/file.c
+++ b/file.c
@@ -3983,8 +3983,9 @@ cf_save_packets(capture_file *cf, const char *fname, guint save_format,
simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK,
file_rename_error_message(errno), fname);
#ifdef _WIN32
- /* Attempt to reopen the file descriptors using fname. */
- if (!wtap_fdreopen(cf->wth, fname, &err, compressed)) {
+ /* Attempt to reopen the random file descriptor using fname.
+ (At this point, the sequential file descriptor is closed.) */
+ if (!wtap_fdreopen(cf->wth, fname, &err)) {
/* Oh, well, we're screwed. */
simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK,
file_open_error_message(err, FALSE), fname);